@@ -14,8 +14,12 @@ from unittestreport import TestRunner
 suite = unittest.defaultTestLoader.loadTestsFromTestCase(TestClass)
 runner = TestRunner(suite=suite,
                     title="前程贷接口自动化执行结果",
-                    templates=1)
+                    templates=2)
+
 runner.run()
 
-runner.send_email(host="smtp.qq.com", port=465, user="musen_nmb@qq.com", password="algmmzptupjccbab",
-                  to_addrs="3247119728@qq.com")
+# runner.send_email(host="smtp.qq.com",
+#                   port=465,
+#                   user="musen_nmb@qq.com",
+#                   password="algmmzptupjccbab",
+#                   to_addrs="3247119728@qq.com")
