@@ -10,18 +10,27 @@ Company:湖南零檬信息技术有限公司
 
 import unittest
 
-from unittestreport import ddt, data
+from unittestreport.core.dataDriver import ddt, list_data,json_data,yaml_data
 
 
 @ddt
 class TestClass(unittest.TestCase):
-    @data([11, 22, 33, 44, 55])
-    def test_case(self, data):
-        """测试"""
-        print("data", data)
-        a = 100
-        b = 99
-        assert a == b
+    cases = [{'case_id': 1, 'title': '用例1', 'data': '用例参数', 'expected': '预期结果'},
+             {'case_id': 2, 'title': '用例2', 'data': '用例参数', 'expected': '预期结果'},
+             {'case_id': 3, 'title': '用例3', 'data': '用例参数', 'expected': '预期结果'}]
+
+    # @list_data(cases)
+    # def test_case(self, data):
+    #     pass
+
+    @json_data("cases.json")
+    def test_case01(self, data):
+        pass
+
+    # @yaml_data("cases.yaml")
+    # def test_case02(self, data):
+    #     pass
+    #
 
 # class TestClass(unittest.TestCase):
 #
